#IF 0  ' 

         Iterative file merge tool

         DESCRIPTION Main file is iteratively scanned for #INCLUDE statements and on each pass
                     replaces the #INCLUDE line with the contents of each file. When there are
                     no #INCLUDE statements left it writes the result to a new BAS file named
                     with a leading "merged_"
                     
         NOTE that system include files are excluded to avoid un-necessary file size.

         Build with PBCC50


#ENDIF ' 

MACRO pause(txtmsg)

    StdOut chr$(13,10) + txtmsg
    Do
      sleep 1
    Loop while inkey$ = ""

END MACRO

' 

FUNCTION PBmain as LONG

    LOCAL lcnt  as DWORD
    LOCAL cntr  as DWORD
    LOCAL iflag as DWORD
    LOCAL fl    as DWORD
    LOCAL pcnt  as DWORD

    cmd$ = command$

    If exist(cmd$) Then                     ' test if command line file exists
      Open cmd$ for Binary as #1
        Get$ #1,lof(1),infile$
      Close #1
    Else
      StdOut "Cannot find that file"
      Exit FUNCTION
    End If

    pcnt = 0                                ' set the pass counter to zero

  startlp:
    ! add pcnt, 1
    StdOut "pass"+str$(pcnt)                ' display the pass number
    iflag = 0
    lcnt = ParseCount(infile$,chr$(13,10))  ' get the line count
    ! add lcnt, 1

    dim arr(lcnt) as STRING                 ' dimension an array of lcnt members
    Parse infile$, arr$(), chr$(13,10)      ' parse lines into a dynamic string array
    infile$ = ""                            ' clear the source string once array is loaded
    cntr = 0                                ' set array index to zero

  ' -----------------------------------

    Do
      If left$(ltrim$(lcase$(arr(cntr))),8) = "#include" Then

        tmp$ = arr(cntr)

      ' ----------------------------------------------
      ' get te path and file name from the source line
      ' and remove "#include" and any trailing comment
      ' ----------------------------------------------
        arr(cntr) = lcase$(decomment$(arr(cntr)))
        arr(cntr) = ltrim$(remove$(arr(cntr),"#include"))
        arr(cntr) = remove$(arr(cntr),chr$(34))

        nam$ = NameFromPath(arr(cntr))      ' strip the path from the file name if it has a path

        If sysinclude(nam$) = 1 Then        ' test if the file name is a system include file
          arr(cntr) = tmp$                  ' reset string to original
          ! jmp bypass                      ' exclude it if it is
        End If

        If exist(arr(cntr)) Then            ' test if the file exists
          tnm$ = arr(cntr)
          Open arr(cntr) for Binary as #1   ' load it into memory if it does
            fl = lof(1)
            StdOut "Merging " + tnm$
            Get$ #1,fl,arr(cntr)            ' replace #INCLUDE line with file content
            iflag = 1                       ' set the iteration flag
          Close #1
        End If

      End If

    bypass:
      ! add cntr, 1
    Loop while cntr < lcnt

  ' -----------------------------------

    infile$ = join$(arr(),chr$(13,10))      ' rebuild modified file
    erase arr()                             ' erase the array

    If iflag = 1 Then
      ! jmp startlp                         ' iterate if flag set
    End If

    outfile$ = "merged_"+cmd$               ' construct the output file name

    Open outfile$ for Output as #1
      Print #1, infile$;                    ' write it to disk
    Close #1

    StdOut outfile$+" written to disk at" + str$(len(infile$)) + " bytes"

    pause("Press any key to quit ....")

End FUNCTION

' 

FUNCTION exist(fname$) as LONG
  FUNCTION = Len( Dir$(fname$, 17) ) > 0
END FUNCTION

' 

FUNCTION decomment$(src$)

  ' --------------------------------------------
  ' remove "'" comment that is not within double
  ' quotes and right trim the string
  ' --------------------------------------------
    #REGISTER NONE

    LOCAL ptxt as DWORD

    ptxt = StrPtr(src$)

    ! mov esi, ptxt
    ! sub esi, 1

  lbl0:
    ! add esi, 1
    ! movzx edi, BYTE PTR [esi]
    ! test edi, edi
    ! jz dcout
    ! cmp edi, 34                       ; branch on double quote
    ! je dquotes
    ! cmp edi, 39                       ; change comment character here
    ! jne lbl0
    ! jmp dcout

  dquotes:
    ! add esi, 1
    ! movzx edi, BYTE PTR [esi]
    ! test edi, edi
    ! jz qterror
    ! cmp edi, 34                       ; double quote
    ! je lbl0
    ! jmp dquotes

  qterror:
    FUNCTION = src$                     ' just return the original string on a quote error
    Exit FUNCTION

  dcout:
    ! sub esi, ptxt
    ! mov ptxt, esi                     ; reuse the variable

    FUNCTION = rtrim$(left$(src$,ptxt))

End FUNCTION

' 

FUNCTION NameFromPath(src$) as STRING

    #REGISTER NONE

    LOCAL psrc as DWORD
    LOCAL lsrc as DWORD

    psrc = StrPtr(src$)                 ' get the source address

    ! mov esi, psrc                     ; load te source address
    ! or ecx, -1                        ; write -1 to ECX
    ! xor edx, edx                      ; clear E#DX

  lbl0:
    ! add ecx, 1
    ! cmp BYTE PTR [esi+ecx], 0         ; test for zero
    ! je lbl1                           ; exit lbl0 on zero
    ! cmp BYTE PTR [esi+ecx], "\"       ; test for \
    ! jne lbl0
    ! mov edx, ecx                      ; store last \ offset
    ! jmp lbl0

  lbl1:
    ! test edx, edx                     ; check if EDX is changed
    ! jz lbl2                           ; jump forward if not
    ! add edx, 1                        ; add 1 to correct length

  lbl2:
    ! mov lsrc, ecx                     ; calculate right string length
    ! sub lsrc, edx

    FUNCTION = right$(src$,lsrc)        ' return that portion of the string

END FUNCTION

' 

FUNCTION sysinclude(a$) as DWORD

    #REGISTER NONE

    LOCAL var as DWORD
    var = StrPtr(a$)
    ! mov eax, var

    ! cmp BYTE PTR [eax+0], "a"
    ! jne lbl0
    ! cmp BYTE PTR [eax+1], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "c"
    ! jne lbl1
    ! cmp BYTE PTR [eax+3], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' accctrl.inc
    EXIT FUNCTION
  ' -------------------
  lbl1:
    ! cmp BYTE PTR [eax+2], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' aclapi.inc
    EXIT FUNCTION
  ' -------------------
  lbl0:
    ! cmp BYTE PTR [eax+0], "c"
    ! jne lbl2
    ! cmp BYTE PTR [eax+1], "o"
    ! jne lbl3
    ! cmp BYTE PTR [eax+2], "m"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "d"
    ! jne lbl4
    ! cmp BYTE PTR [eax+4], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "g"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "3"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "2"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' comdlg32.inc
    EXIT FUNCTION
  ' -------------------
  lbl4:
    ! cmp BYTE PTR [eax+3], "m"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' commctrl.inc
    EXIT FUNCTION
  ' -------------------
  lbl3:
    ! cmp BYTE PTR [eax+1], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' cpl.inc
    EXIT FUNCTION
  ' -------------------
  lbl2:
    ! cmp BYTE PTR [eax+0], "d"
    ! jne lbl5
    ! cmp BYTE PTR [eax+1], "d"
    ! jne lbl6
    ! cmp BYTE PTR [eax+2], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' ddt.inc
    EXIT FUNCTION
  ' -------------------
  lbl6:
    ! cmp BYTE PTR [eax+1], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "g"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "v"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' digitalv.inc
    EXIT FUNCTION
  ' -------------------
  lbl5:
    ! cmp BYTE PTR [eax+0], "h"
    ! jne lbl7
    ! cmp BYTE PTR [eax+1], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "m"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "h"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "e"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' htmlhelp.inc
    EXIT FUNCTION
  ' -------------------
  lbl7:
    ! cmp BYTE PTR [eax+0], "i"
    ! jne lbl8
    ! cmp BYTE PTR [eax+1], "m"
    ! jne lbl9
    ! cmp BYTE PTR [eax+2], "e"
    ! jne lbl10
    ! cmp BYTE PTR [eax+3], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' ime.inc
    EXIT FUNCTION
  ' -------------------
  lbl10:
    ! cmp BYTE PTR [eax+2], "m"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' imm.inc
    EXIT FUNCTION
  ' -------------------
  lbl9:
    ! cmp BYTE PTR [eax+1], "n"
    ! jne lbl11
    ! cmp BYTE PTR [eax+2], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' initctrl.inc
    EXIT FUNCTION
  ' -------------------
  lbl11:
    ! cmp BYTE PTR [eax+1], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "h"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' iphlpapi.inc
    EXIT FUNCTION
  ' -------------------
  lbl8:
    ! cmp BYTE PTR [eax+0], "l"
    ! jne lbl12
    ! cmp BYTE PTR [eax+1], "m"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "a"
    ! jne lbl13
    ! cmp BYTE PTR [eax+3], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "e"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' lmaccess.inc
    EXIT FUNCTION
  ' -------------------
  lbl13:
    ! cmp BYTE PTR [eax+2], "e"
    ! jne lbl14
    ! cmp BYTE PTR [eax+3], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' lmerr.inc
    EXIT FUNCTION
  ' -------------------
  lbl14:
    ! cmp BYTE PTR [eax+2], "w"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "k"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' lmwksta.inc
    EXIT FUNCTION
  ' -------------------
  lbl12:
    ! cmp BYTE PTR [eax+0], "m"
    ! jne lbl15
    ! cmp BYTE PTR [eax+1], "c"
    ! jne lbl16
    ! cmp BYTE PTR [eax+2], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "v"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' mciavi.inc
    EXIT FUNCTION
  ' -------------------
  lbl16:
    ! cmp BYTE PTR [eax+1], "d"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "3"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "2"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' mdi32.inc
    EXIT FUNCTION
  ' -------------------
  lbl15:
    ! cmp BYTE PTR [eax+0], "n"
    ! jne lbl17
    ! cmp BYTE PTR [eax+1], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "e"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' ntsecapi.inc
    EXIT FUNCTION
  ' -------------------
  lbl17:
    ! cmp BYTE PTR [eax+0], "p"
    ! jne lbl18
    ! cmp BYTE PTR [eax+1], "b"
    ! jne lbl19
    ! cmp BYTE PTR [eax+2], "f"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "o"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "m"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' pbforms.inc
    EXIT FUNCTION
  ' -------------------
  lbl19:
    ! cmp BYTE PTR [eax+1], "o"
    ! jne lbl20
    ! cmp BYTE PTR [eax+2], "w"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "o"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "f"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' powrprof.inc
    EXIT FUNCTION
  ' -------------------
  lbl20:
    ! cmp BYTE PTR [eax+1], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "h"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' prsht.inc
    EXIT FUNCTION
  ' -------------------
  lbl18:
    ! cmp BYTE PTR [eax+0], "r"
    ! jne lbl21
    ! cmp BYTE PTR [eax+1], "a"
    ! jne lbl22
    ! cmp BYTE PTR [eax+2], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "3"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "2"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' ras32.inc
    EXIT FUNCTION
  ' -------------------
  lbl22:
    ! cmp BYTE PTR [eax+1], "e"
    ! jne lbl23
    ! cmp BYTE PTR [eax+2], "a"
    ! jne lbl24
    ! cmp BYTE PTR [eax+3], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "o"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' reason.inc
    EXIT FUNCTION
  ' -------------------
  lbl24:
    ! cmp BYTE PTR [eax+2], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "o"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "u"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "e"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "h"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' resource.h
    EXIT FUNCTION
  ' -------------------
  lbl23:
    ! cmp BYTE PTR [eax+1], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "h"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "e"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "d"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' richedit.inc
    EXIT FUNCTION
  ' -------------------
  lbl21:
    ! cmp BYTE PTR [eax+0], "s"
    ! jne lbl25
    ! cmp BYTE PTR [eax+1], "e"
    ! jne lbl26
    ! cmp BYTE PTR [eax+2], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "e"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "x"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' secext.inc
    EXIT FUNCTION
  ' -------------------
  lbl26:
    ! cmp BYTE PTR [eax+1], "h"
    ! jne lbl27
    ! cmp BYTE PTR [eax+2], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "w"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' shlwapi.inc
    EXIT FUNCTION
  ' -------------------
  lbl27:
    ! cmp BYTE PTR [eax+1], "u"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "b"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "u"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "h"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' subauth.inc
    EXIT FUNCTION
  ' -------------------
  lbl25:
    ! cmp BYTE PTR [eax+0], "t"
    ! jne lbl28
    ! cmp BYTE PTR [eax+1], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "h"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "e"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "3"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "2"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' tlhelp32.inc
    EXIT FUNCTION
  ' -------------------
  lbl28:
    ! cmp BYTE PTR [eax+0], "v"
    ! jne lbl29
    ! cmp BYTE PTR [eax+1], "b"
    ! jne lbl30
    ! cmp BYTE PTR [eax+2], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "3"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "2"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' vbapi32.inc
    EXIT FUNCTION
  ' -------------------
  lbl30:
    ! cmp BYTE PTR [eax+1], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "r"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' vcr.inc
    EXIT FUNCTION
  ' -------------------
  lbl29:
    ! cmp BYTE PTR [eax+0], "w"
    ! jne notfound
    ! cmp BYTE PTR [eax+1], "e"
    ! jne lbl31
    ! cmp BYTE PTR [eax+2], "b"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "u"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "b"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' webpub.inc
    EXIT FUNCTION
  ' -------------------
  lbl31:
    ! cmp BYTE PTR [eax+1], "f"
    ! jne lbl32
    ! cmp BYTE PTR [eax+2], "e"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "x"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' wfext.inc
    EXIT FUNCTION
  ' -------------------
  lbl32:
    ! cmp BYTE PTR [eax+1], "i"
    ! jne lbl33
    ! cmp BYTE PTR [eax+2], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "3"
    ! jne lbl34
    ! cmp BYTE PTR [eax+4], "2"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "a"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' win32api.inc
    EXIT FUNCTION
  ' -------------------
  lbl34:
    ! cmp BYTE PTR [eax+3], "h"
    ! jne lbl35
    ! cmp BYTE PTR [eax+4], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "p"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' winhttp.inc
    EXIT FUNCTION
  ' -------------------
  lbl35:
    ! cmp BYTE PTR [eax+3], "i"
    ! jne lbl36
    ! cmp BYTE PTR [eax+4], "n"
    ! jne lbl37
    ! cmp BYTE PTR [eax+5], "e"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' wininet.inc
    EXIT FUNCTION
  ' -------------------
  lbl37:
    ! cmp BYTE PTR [eax+4], "o"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "t"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+12], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' winioctl.inc
    EXIT FUNCTION
  ' -------------------
  lbl36:
    ! cmp BYTE PTR [eax+3], "w"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "l"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "x"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' winwlx.inc
    EXIT FUNCTION
  ' -------------------
  lbl33:
    ! cmp BYTE PTR [eax+1], "s"
    ! jne notfound
    ! cmp BYTE PTR [eax+2], "2"
    ! jne lbl38
    ! cmp BYTE PTR [eax+3], "_"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "3"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "2"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' ws2_32.inc
    EXIT FUNCTION
  ' -------------------
  lbl38:
    ! cmp BYTE PTR [eax+2], "o"
    ! jne notfound
    ! cmp BYTE PTR [eax+3], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+4], "k"
    ! jne notfound
    ! cmp BYTE PTR [eax+5], "3"
    ! jne notfound
    ! cmp BYTE PTR [eax+6], "2"
    ! jne notfound
    ! cmp BYTE PTR [eax+7], "."
    ! jne notfound
    ! cmp BYTE PTR [eax+8], "i"
    ! jne notfound
    ! cmp BYTE PTR [eax+9], "n"
    ! jne notfound
    ! cmp BYTE PTR [eax+10], "c"
    ! jne notfound
    ! cmp BYTE PTR [eax+11], 0
    ! jne notfound
  ' -------------------
    FUNCTION = 1 ' wsock32.inc
    EXIT FUNCTION
  ' -------------------
    
  notfound:
    FUNCTION = 0

END FUNCTION

' 
